@@ -39,7 +39,7 @@
 static char bootprog_name[] = "Compaq OHH BootLoader";
 static char bootprog_date[] = DATE;
 
-static char cvsversion[] = "$Id: bootldr.c,v 1.27 2000/09/08 20:50:57 france Exp $";
+static char cvsversion[] = "$Id: bootldr.c,v 1.29 2000/11/21 13:29:05 jamey Exp $";
 
 #define USE_XMODEM
 #define BOOT_ALTKERNEL
@@ -50,7 +50,9 @@ static char cvsversion[] = "$Id: bootldr.c,v 1.27 2000/09/08 20:50:57 france Exp
 #include "btusb.h"
 #include "heap.h"
 #include "xmodem.h"
+#ifdef __linux__
 #include <asm-arm/setup.h>
+#endif
 #include "sa1100.h"
 #include "bsdsum.h"
 #include "architecture.h"
@@ -69,6 +71,8 @@ long paramoldvalue;
 		
 #define ROUNDUP(v,szpwr2) (((v)+((szpwr2)-1))&~(szpwr2-1))
 
+extern void *SerBase;
+
 #if 0
 void reboot(void);
 #endif
@@ -131,6 +135,7 @@ void command_params_show(int argc, const char **argv);
 void command_params_eval(int argc, const char **argv);
 void command_params_save(int argc, const char **argv);
 void testCirrusCardbusBridge(int argc, const char **argv);
+void command_netboot(int argc, const char **argv);
 
 void parseargs(char *argstr, int *argc_p, char **argv);
 void unparseargs(char *argstr, int argc, const char **argv);
@@ -141,7 +146,7 @@ void bootmenu(void);
 
 void monitorConfigureMMU(void);
 
-#ifdef CONFIG_GZIP      
+#if defined(CONFIG_GZIP) || defined(CONFIG_GZIP_REGION)
 int gunzip_region(char*   src,    char*   dst,
 		  long len, const char *name);
 #endif
@@ -158,7 +163,7 @@ static struct bootblk_command commands[] = {
   { "save",   command_save, "save [all | bootldr | debugger | flash | kernel | ramdisk | params | usercode | world | altkernel]" },
   { "peek",   command_peek, "peek ram|flash|int|short|byte <addr>" },
   { "poke",   command_poke, "poke ram|flash|int|short|byte <addr>" },
-#ifdef CONFIG_BITSY
+#if defined(CONFIG_BITSY) || defined(CONFIG_ASSABET) || defined(CONFIG_NEPONSET)
   { "breakpoint", command_breakpoint, "breakpoint" },
 #endif
   { "qflash", command_qflash, "qflash [cfi|id] <waddr> -- query flash" },
@@ -176,6 +181,7 @@ static struct bootblk_command commands[] = {
   { "evalparams", command_params_eval, "evalparams"},
   { "params", command_params, "params [eval|show|save|reset]"},
   { "flash_type", command_flash_type, "flash_type <flashtype>"},
+  { "netboot", command_netboot, "netboot" },
 #if 0
   { "cardbus", testCirrusCardbusBridge, "cardbus" },
 #endif
@@ -463,9 +469,12 @@ void putc(char c)
 #ifdef CONFIG_SKIFF
   while (CSR_READ_BYTE(UARTFLG_REG) & UART_TX_FIFO_BUSY);
   CSR_WRITE_BYTE(UARTDR_REG,c);
-#elif defined(CONFIG_BITSY)
+#elif defined(CONFIG_BITSY) || defined(CONFIG_NEPONSET)
   while (!((*(volatile long *)SA1100_UART3_UTSR1) & SA1100_UTSR1_TNF)); /* wait until TX FIFO not full */
   *(byte *)SA1100_UART3_UTDR = c;
+#elif defined(CONFIG_ASSABET)
+  while (!((*(volatile long *)SA1100_UART1_UTSR1) & SA1100_UTSR1_TNF));
+  *(byte *)SA1100_UART1_UTDR = c;
 #else
 #error no definition for putc for this architecture
 #endif
@@ -473,12 +482,12 @@ void putc(char c)
 
 void putstr(const char *str)
 {
-   extern void *Ser3Base;
+   extern void *SerBase;
    if (str == NULL)
       return;
    while (*str != '\0') {
-#ifdef CONFIG_BITSY
-         PrintChar(*str, Ser3Base) ;
+#if defined(CONFIG_BITSY) || defined(CONFIG_ASSABET)
+         PrintChar(*str, SerBase) ;
 #else
          putc(*str) ;
 #endif
@@ -645,7 +654,7 @@ static struct ebsaboot bootinfo = {
    0x20000000,		/* physical addr of arg page */
    NULL,		/* kernel args string pointer */
    (pd_entry_t *)MMU_TABLE_START,	/* active L1 page table */
-   0,		        /* start of physical memory */
+   0,			/* start of physical memory */
    DRAM_SIZE,		/* end of physical memory */
    SZ_2M+SZ_1M,         /* start of avail phys memory */
    48000000,		/* fclk frequency */
@@ -703,11 +712,17 @@ byte awaitkey(unsigned long delay, int *error_p)
 #ifdef CONFIG_SKIFF
     while (((CSR_READ_BYTE(UARTFLG_REG) & UART_RX_FIFO_EMPTY)) && i)
 	i--;
-#else
+#elif defined(CONFIG_BITSY) || defined(CONFIG_NEPONSET)
     {
        while ((!((*(volatile long *)SA1100_UART3_UTSR1) & SA1100_UTSR1_RNE)) && i)
           i--;
     }
+#elif defined(CONFIG_ASSABET)
+    {
+       while ((!((*(volatile long *)SA1100_UART1_UTSR1) & SA1100_UTSR1_RNE)) && i)
+          i--;
+    }
+#else
 #endif
     
     if (i) {
@@ -715,20 +730,26 @@ byte awaitkey(unsigned long delay, int *error_p)
 #ifdef CONFIG_SKIFF
       c = CSR_READ_BYTE(UARTDR_REG);
       errors = CSR_READ_BYTE(RXSTAT_REG);
-#else
+#elif defined(CONFIG_BITSY) || defined(CONFIG_NEPONSET)
       c = *(volatile long *)SA1100_UART3_UTDR;
       errors = (*(volatile long *)SA1100_UART3_UTSR1) & SA1100_UTSR1_ERROR_MASK;
+#elif defined(CONFIG_ASSABET)
+      c = *(volatile long *)SA1100_UART1_UTDR;
+      errors = (*(volatile long *)SA1100_UART1_UTSR1) & SA1100_UTSR1_ERROR_MASK;
+#else
 #endif
-      if (!errors) /* if no receive errors found.. */
-	break; /* get out of here */
+      if (!errors)
+	  break;
     } else {
-      c = 0; /* no one pressed a key. return a NULL and get out of here */
-      errors = -1;
-      break;
-    }
+	c = 0; /* no one pressed a key. return a NULL and get out of here */
+	errors = -1;
+	break;
+      }
   }
   if (error_p != NULL)
+  {
     *error_p = errors;
+  }
   return(c);
 }
 
@@ -742,11 +763,16 @@ byte getc(void) {
    /* must read UARTDR_REG before RXSTAT_REG */
    c =  CSR_READ_BYTE(UARTDR_REG);
    rxstat = CSR_READ_BYTE(RXSTAT_REG);
-#elif defined(CONFIG_BITSY)
+#elif defined(CONFIG_BITSY) || defined(CONFIG_NEPONSET)
    while ((!((*(volatile long *)SA1100_UART3_UTSR1) & SA1100_UTSR1_RNE)))
      /* spin wait */;
    c = *(volatile byte *)SA1100_UART3_UTDR;
    rxstat = (*(volatile byte *)SA1100_UART3_UTSR1) & SA1100_UTSR1_ERROR_MASK;
+#elif defined(CONFIG_ASSABET)
+   while ((!((*(volatile long *)SA1100_UART1_UTSR1) & SA1100_UTSR1_RNE)))
+     /* spin wait */;
+   c = *(volatile byte *)SA1100_UART1_UTDR;
+   rxstat = (*(volatile byte *)SA1100_UART1_UTSR1) & SA1100_UTSR1_ERROR_MASK;
 #else
 #error no architecture defined for getc
 #endif
@@ -1109,13 +1135,14 @@ int main()
      struct bootblk_param *dram_size_param = get_param("dram_size");
 #ifdef CONFIG_SKIFF
      struct bootblk_param *mem_fclk_21285_param = get_param("mem_fclk_21285");
+     struct bootblk_param *maclsbyte_param = get_param("maclsbyte");
 #endif
      long system_rev = get_system_rev();
      long dram_size;
 #ifdef CONFIG_SKIFF
      dram_size = ((system_rev&SYSTEM_REV_MAJOR_MASK) == SYSTEM_REV_SKIFF_V2) ? DRAM_SIZE : SZ_16M;
 #endif
-#ifdef CONFIG_BITSY
+#if defined(CONFIG_BITSY) || defined(CONFIG_ASSABET)
      /* assumes one bank of DRAM and that DRAM_BASE0 is not in the cache */
      *(long *)(DRAM_BASE0 + SZ_64M) = SZ_64M;
      *(long *)(DRAM_BASE0 + SZ_32M) = SZ_32M;
@@ -1150,9 +1177,16 @@ int main()
      default:
         mem_fclk_21285_param->value = 33333333; break;
      }
+     if (maclsbyte_param)
+       maclsbyte_param->value = get_maclsbyte();
+
      putstr("memclk_hz: ");
      putstr(((system_rev & SYSTEM_REV_MEMCLK_MASK) == SYSTEM_REV_MEMCLK_33MHZ) 
             ? "33MHz\r\n" : "48MHz\r\n");
+     /* this string should agree with the MAC in btpci.c */
+     if (maclsbyte_param) {
+       putstr("MAC=08:00:2b:00:01:"); putHexInt8(maclsbyte_param->value); putstr("\r\n");
+     }
 #endif
      putLabeledWord("dram_size: ", dram_size);
      
@@ -1245,6 +1279,13 @@ void command_flash_type(int argc, const char **argv)
   }
 }
 
+void command_netboot(int argc, const char **argv)
+{
+#if 0
+    netboot();
+#endif
+}
+
 /* can have arguments or not */
 void command_params(int argc, const char **argv)
 {
@@ -1262,7 +1303,7 @@ void command_params(int argc, const char **argv)
 }
 
 
-
+#ifdef __linux__
 void setup_linux_params(long bootimg_dest, long initrd_start, long initrd_size, 
 			long memc_ctrl_reg, long mem_fclk_21285, long dram_size,
 			const char *cmdline, int flashroot)
@@ -1327,7 +1368,7 @@ void setup_linux_params(long bootimg_dest, long initrd_start, long initrd_size,
    putstr(cmdline);
    putstr("\r\n");
 }
-
+#endif
 
 /*
  * boot_kernel
@@ -1351,7 +1392,6 @@ static void boot_kernel(const char *root_filesystem_name,
    int i;
    char *os;
    long bootingLinux = 0;
-   long bootNetBSD = 0;
    long force_unzip_kernels = 0;
    long linuxEntryPoint = 0;
    long unzip_ramdisk = 0;
@@ -1402,7 +1442,7 @@ static void boot_kernel(const char *root_filesystem_name,
    } else if (strncmp(os, "netbsd", 5) == 0) {
       putstr("os="), putstr(os); putstr("\r\n");
       putstr("expecting to boot a netbsd kernel\r\n");
-      bootingLinux = 1;
+      bootingLinux = 0;
    }
 
 
@@ -1530,7 +1570,7 @@ static void boot_kernel(const char *root_filesystem_name,
        } else if (compressed_rd_size != -1) {
           initrd_start = compressed_rd_start;
        }
-#ifdef CONFIG_GZIP      
+#if defined(CONFIG_GZIP) || defined(CONFIG_GZIP_REGION)
      }
 #endif /* CONFIG_GZIP */
 
@@ -1557,8 +1597,10 @@ static void boot_kernel(const char *root_filesystem_name,
         putstr("\r\n");
 
         putstr("setting boot parameters\r\n");
+#ifdef __linux__
         setup_linux_params(kernel_image_dest, initrd_start, compressed_rd_size,
                           memc_ctrl_reg, mem_fclk_21285, dram_size, boot_args, flashroot);
+#endif
      }
 
      putLabeledWord("linuxEntryPoint=", linuxEntryPoint);
@@ -1600,9 +1642,13 @@ static void boot_kernel(const char *root_filesystem_name,
       bootinfo.bt_args = boot_args;
       bootinfo.bt_vargp = (u_int32_t)boot_args & PAGE_MASK;
       bootinfo.bt_pargp = (u_int32_t)boot_args & PAGE_MASK;
-
-      putstr("done!\r\nJumping to 0xF0000020..\r\n");
+      for(i = 0 ; i < (DRAM_SIZE0 - SZ_2M) ; i += SZ_1M) {
+	unsigned long dram_paddr = DRAM_BASE + i;
+	unsigned long dram_vaddr = 0xf0000000 + i;
+	mmu_table[dram_vaddr >> 20] = dram_paddr | MMU_SECDESC | MMU_CACHEABLE;
+      }
       flush_caches();
+      putstr("done!\r\nJumping to 0xF0000020..\r\n");
       boot(&bootinfo,0xF0000020);
    } else {
      putstr("Corrupt kernel image\r\n");
@@ -1722,11 +1768,7 @@ void command_boot_nfsroot(int argc, const char **argv)
 
 void command_display(int argc, const char **argv)
 {
-
-  /* char buf[9];
-     binarytohex(buf,value,4); */
-
- #ifdef CONFIG_BITSY
+#if defined(CONFIG_BITSY) || defined(CONFIG_ASSABET) || defined(CONFIG_NEPONSET)
    putstr("\r\nSA1100 Registers:\r\n" );
      putLabeledWord("   SA1100_UART3:  ", (long) SA1100_UART3_UTCR0);
        putLabeledAddrWord( "      UTCR0   0x00 ", (long *)SA1100_UART3_UTCR0);
@@ -2279,7 +2321,7 @@ void command_poke_ram(int argc, const char **argv)
 }
 
 
-#ifdef CONFIG_BITSY
+#if defined(CONFIG_BITSY) || defined(CONFIG_ASSABET) || defined(CONFIG_NEPONSET)
 extern unsigned long delayedBreakpointPC;
 void command_breakpoint(int argc, const char **argv)
 {
@@ -2575,7 +2617,7 @@ void update_baudrate(struct bootblk_param *param)
    unsigned long h_ubrlcr = 0;
 
    switch ( baudrate ) {
-#ifdef CONFIG_BITSY
+#if defined(CONFIG_BITSY) || defined(CONFIG_ASSABET) || defined(CONFIG_NEPONSET)
    case 230400:
      break;
    case 115200:
@@ -2625,7 +2667,7 @@ void update_baudrate(struct bootblk_param *param)
    ubrlcr = (fclk_hz / 64 / baudrate)-1;
    h_ubrlcr = csr[H_UBRLCR_REG];
 
-#elif defined(CONFIG_BITSY)
+#elif defined(CONFIG_BITSY) || defined(CONFIG_ASSABET) || defined(CONFIG_NEPONSET)
    ubrlcr = (3686400 / 16 / baudrate) - 1;
 #else
    #error no architecture defined in update_baudrate
